==> frostiful-2.2.8%2B1.21.8-sources.jar: com/github/thedeathlycow/frostiful/client/render/model/IceSkateModel.java <==
package com.github.thedeathlycow.frostiful.client.render.model;

import net.minecraft.class_10034;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_572;
import net.minecraft.class_6230;
import net.minecraft.class_630;
import net.minecraft.client.model.*;

public class IceSkateModel<T extends class_10034> extends class_572<T> {

    public IceSkateModel(class_630 root) {
        super(root);
        this.method_2805(false);
        this.field_3397.field_3665 = true;
        this.field_3392.field_3665 = true;
    }

    public static class_5607 getTexturedModelData() {
        class_5609 modelData = class_572.method_32011(class_5605.field_27715, 0.0f);
        class_5610 root = modelData.method_32111();
        root.method_32117(
                class_6230.field_32632,
                class_5606.method_32108()
                        // blade base
                        .method_32101(0, 0)
                        .method_32098(-1f, 13.0F, -4.0F, 2.0F, 0.0F, 8.0F, class_5605.field_27715)
                        // blade cross
                        .method_32101(8, 0)
                        .method_32098(0.0F, 13.0F, -4.0F, 0.0F, 1.0F, 8.0F, class_5605.field_27715)
                        // blade back
                        .method_32101(0, 2)
                        .method_32098(-1f, 11F, -4.0F, 2.0F, 2.0F, 0.0F, class_5605.field_27715)
                        // blade front
                        .method_32101(0, 0)
                        .method_32098(-1f, 11F, 4.0F, 2.0F, 2.0F, 0.0F, class_5605.field_27715),
                class_5603.method_32090(-1.9f, 12.0f, 0.0f)
        );

        root.method_32117(
                class_6230.field_32631,
                class_5606.method_32108()
                        .method_32096()
                        .method_32101(0, 0)
                        .method_32098(-1f, 13.0F, -4.0F, 2.0F, 0.0F, 8.0F, class_5605.field_27715)

                        .method_32101(8, 0)
                        .method_32098(0.0F, 13.0F, -4.0F, 0.0F, 1.0F, 8.0F, class_5605.field_27715)

                        .method_32101(0, 2)
                        .method_32098(-1f, 11F, -4.0F, 2.0F, 2.0F, 0.0F, class_5605.field_27715)
                        .method_32101(0, 0)
                        .method_32098(-1f, 11f, 4.0F, 2.0F, 2.0F, 0.0F, class_5605.field_27715),
                class_5603.method_32090(1.9f, 12.0f, 0.0f)
        );
        return class_5607.method_32110(modelData, 32, 32);
    }

//    @Override
//    public void render(MatrixStack matrices, VertexConsumer vertexConsumer, int light, int overlay, float red, float green, float blue, float alpha) {
//        leftLeg.render(matrices, vertexConsumer, light, overlay, red, green, blue, alpha);
//        rightLeg.render(matrices, vertexConsumer, light, overlay, red, green, blue, alpha);
//    }
}

==> frostiful-2.2.9%2B1.21.9-sources.jar: com/github/thedeathlycow/frostiful/client/render/model/IceSkateModel.java <==
package com.github.thedeathlycow.frostiful.client.render.model;

import net.minecraft.class_10034;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_572;
import net.minecraft.class_6230;
import net.minecraft.class_630;
import net.minecraft.class_9953;
import net.minecraft.client.model.*;

public class IceSkateModel<T extends class_10034> extends class_572<T> {
    public static final class_9953 BABY_TRANSFORMER = class_9953.scaling(0.5F);

    public IceSkateModel(class_630 root) {
        super(root);
        this.method_2805(false);
        this.field_3397.field_3665 = true;
        this.field_3392.field_3665 = true;
    }

    public static class_5607 getTexturedModelData() {
        class_5609 modelData = class_572.method_32011(class_5605.field_27715, 0.0f);
        class_5610 root = modelData.method_32111();
        root.method_32117(
                class_6230.field_32632,
                class_5606.method_32108()
                        // blade base
                        .method_32101(0, 0)
                        .method_32098(-1f, 13.0F, -4.0F, 2.0F, 0.0F, 8.0F, class_5605.field_27715)
                        // blade cross
                        .method_32101(8, 0)
                        .method_32098(0.0F, 13.0F, -4.0F, 0.0F, 1.0F, 8.0F, class_5605.field_27715)
                        // blade back
                        .method_32101(0, 2)
                        .method_32098(-1f, 11F, -4.0F, 2.0F, 2.0F, 0.0F, class_5605.field_27715)
                        // blade front
                        .method_32101(0, 0)
                        .method_32098(-1f, 11F, 4.0F, 2.0F, 2.0F, 0.0F, class_5605.field_27715),
                class_5603.method_32090(-1.9f, 12.0f, 0.0f)
        );

        root.method_32117(
                class_6230.field_32631,
                class_5606.method_32108()
                        .method_32096()
                        .method_32101(0, 0)
                        .method_32098(-1f, 13.0F, -4.0F, 2.0F, 0.0F, 8.0F, class_5605.field_27715)

                        .method_32101(8, 0)
                        .method_32098(0.0F, 13.0F, -4.0F, 0.0F, 1.0F, 8.0F, class_5605.field_27715)

                        .method_32101(0, 2)
                        .method_32098(-1f, 11F, -4.0F, 2.0F, 2.0F, 0.0F, class_5605.field_27715)
                        .method_32101(0, 0)
                        .method_32098(-1f, 11f, 4.0F, 2.0F, 2.0F, 0.0F, class_5605.field_27715),
                class_5603.method_32090(1.9f, 12.0f, 0.0f)
        );
        return class_5607.method_32110(modelData, 32, 32);
    }

    public static class_5607 getBabyTexturedModelData() {
        return getTexturedModelData().method_62137(field_52918);
    }

//    @Override
//    public void render(MatrixStack matrices, VertexConsumer vertexConsumer, int light, int overlay, float red, float green, float blue, float alpha) {
//        leftLeg.render(matrices, vertexConsumer, light, overlay, red, green, blue, alpha);
//        rightLeg.render(matrices, vertexConsumer, light, overlay, red, green, blue, alpha);
//    }
}
